@@ -1,7 +1,5 @@
 package indirect;
 
-use 5.008;
-
 use strict;
 use warnings;
 
@@ -11,13 +9,13 @@ indirect - Lexically warn about using the indirect object syntax.
 
 =head1 VERSION
 
-Version 0.09_01
+Version 0.01
 
 =cut
 
 our $VERSION;
 BEGIN {
- $VERSION = '0.09_01';
+ $VERSION = '0.01';
 }
 
 =head1 SYNOPSIS
@@ -33,17 +31,15 @@ BEGIN {
 
 =head1 DESCRIPTION
 
-When enabled (or disabled as some may prefer to say, since you actually turn it on by calling C<no indirect>), this pragma warns about indirect object syntax constructs that may have slipped into your code. This syntax is now considered harmful, since its parsing has many quirks and its use is error prone (when C<sub> isn't defined, C<sub $x> is actually interpreted as C<< $x->sub >>).
+When enabled (or disabled as some may prefer, since you actually turn it on by calling C<no indirect>), this pragma warns about indirect object syntax constructs that may have slipped into your code. This syntax is now considered harmful, since its parsing has many quirks and its use is error prone (when C<sub> isn't defined, C<sub $x> is actually interpreted as C<< $x->sub >>).
 
 It currently does not warn when the object is enclosed between braces (like C<meth { $obj } @args>) or for core functions (C<print> or C<say>). This may change in the future, or may be added as optional features that would be enabled by passing options to C<unimport>.
 
-This module is B<not> a source filter.
-
 =head1 METHODS
 
 =head2 C<unimport @opts>
 
-Magically called when C<no indirect @opts> is encountered. Turns the module on. If C<@opts> contains C<':fatal'>, the module will croak on the first indirect syntax met.
+Magically called when C<no indirect @args> is encountered. Turns the module on. If C<@opts> contains C<':fatal'>, the module will croak on the first indirect syntax met.
 
 =head2 C<import>
 
@@ -62,28 +58,22 @@ sub import {
 
 sub unimport {
  (undef, my $type) = @_;
- $^H |= 0x00020000;
  $^H{indirect} = (defined $type and $type eq ':fatal') ? 2 : 1;
 }
 
 =head1 DEPENDENCIES
 
-L<perl> 5.8.
+L<perl> 5.9.4.
 
 L<XSLoader> (standard since perl 5.006).
 
-=head1 CAVEATS
-
-C<meth $obj> (no semicolon) at the end of a file won't be seen as an indirect object syntax, although it will as soon as there is another token before the end (as in C<meth $obj;> or C<meth $obj 1>).
-
-With 5.8 perls, the pragma does not propagate into C<eval STRING>.
-This is due to a shortcoming in the way perl handles the hints hash, which is addressed in perl 5.10.
+Tests require L<IPC::Cmd> (standard since 5.9.5).
 
 =head1 AUTHOR
 
 Vincent Pit, C<< <perl at profvince.com> >>, L<http://www.profvince.com>.
 
-You can contact me by mail or on C<irc.perl.org> (vincent).
+You can contact me by mail or on #perl @ FreeNode (vincent or Prof_Vince).
 
 =head1 BUGS
 
@@ -95,8 +85,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc indirect
 
-Tests code coverage report is available at L<http://www.profvince.com/perl/cover/indirect>.
-
 =head1 ACKNOWLEDGEMENTS
 
 Bram, for motivation and advices.
